@@ -2,6 +2,8 @@
 
 const PREDEFINED_SITELIST = [
     'https://accounts.google.com/*',
+    'https://www.paypal.com/*/cgi-bin/webscr*',
+    'https://www.paypal.com/*/checkoutnow*',
     'https://www.paypal.com/*/signin*',
     'https://www.paypal.com/cgi-bin/webscr*',
     'https://www.paypal.com/checkoutnow*',
@@ -150,7 +152,8 @@ kpxcSites.segmentedTotpExceptionFound = function(form) {
         return false;
     }
 
-    if (document.location.href.startsWith('https://store.steampowered.com') && form.length === 5) {
+    if ((document.location.href.startsWith('https://store.steampowered.com')
+        || document.location.href.startsWith('https://steamcommunity.com/login')) && form.length === 5) {
         return true;
     }
 
