@@ -1,24 +1,21 @@
 'use strict';
 
 class CredentialAutocomplete extends Autocomplete {}
-CredentialAutocomplete.prototype.click = async function(e, input) {
+CredentialAutocomplete.prototype.click = async function(e) {
     if (!e.isTrusted) {
         return;
     }
 
     e.stopPropagation();
 
-    if (input.value !== '') {
-        input.select();
-    }
-
-    const field = this.autocompleteList.find(a => a === input);
+    const field = this.autocompleteList.find(a => a === e.target);
     if (field) {
-        this.showList(field);
+        await this.showList(field);
+        this.updateSearch();
     }
 };
 
-CredentialAutocomplete.prototype.itemClick = async function(e, item, input, uuid) {
+CredentialAutocomplete.prototype.itemClick = async function(e, input, uuid) {
     if (!e.isTrusted) {
         return;
     }
@@ -26,7 +23,7 @@ CredentialAutocomplete.prototype.itemClick = async function(e, item, input, uuid
     e.stopPropagation();
 
     const index = Array.prototype.indexOf.call(e.currentTarget.parentElement.childNodes, e.currentTarget);
-    const usernameValue = item.getElementsByTagName('input')[0].value;
+    const usernameValue = e.target.getElementsByTagName('input')[0].value;
     await this.fillPassword(usernameValue, index, uuid);
 
     this.closeList();
@@ -45,8 +42,7 @@ CredentialAutocomplete.prototype.fillPassword = async function(value, index, uui
     await sendMessage('page_set_login_id', uuid);
 
     const manualFill = await sendMessage('page_get_manual_fill');
-    await kpxc.fillInCredentials(combination, value, uuid, manualFill === ManualFill.PASSWORD);
-    this.input.setAttribute('fetched', true);
+    await kpxcFill.fillInCredentials(combination, value, uuid, manualFill === ManualFill.PASSWORD);
 };
 
 const kpxcUserAutocomplete = new CredentialAutocomplete();
