@@ -252,6 +252,8 @@ kpxcUI.createNotification = function(type, message) {
 
     const styleSheet = createStylesheet('css/notification.css');
     notificationWrapper = notificationWrapper || document.createElement('div');
+    notificationWrapper.style.display = 'none';
+    styleSheet.addEventListener('load', () => notificationWrapper.style.display = 'block');
     this.shadowRoot = notificationWrapper.attachShadow({ mode: 'closed' });
     if (!this.shadowRoot) {
         return;
