@@ -1,8 +1,11 @@
 'use strict';
 
-$(async () => {
+(async () => {
+    resizePopup();
     await initColorTheme();
 
+    $('#lock-database-button').show();
+
     const global = await browser.runtime.getBackgroundPage();
     const tabs = await browser.tabs.query({ active: true, currentWindow: true });
     if (tabs.length === 0) {
@@ -60,19 +63,21 @@ $(async () => {
         filter.focus();
     }
 
-    $('#lock-database-button').click((e) => {
+    $('#lock-database-button').addEventListener('click', (e) => {
         browser.runtime.sendMessage({
             action: 'lock_database'
         });
+
         $('#credentialsList').hide();
         $('#database-not-opened').show();
-        $('#database-error-message').html(tr('errorMessageDatabaseNotOpened'));
+        $('#lock-database-button').hide();
+        $('#database-error-message').textContent = tr('errorMessageDatabaseNotOpened');
     });
 
-    $('#reopen-database-button').click((e) => {
+    $('#reopen-database-button').addEventListener('click', (e) => {
         browser.runtime.sendMessage({
             action: 'get_status',
             args: [ false, true ] // Set forcePopup to true
         });
     });
-});
+})();
